=======
History
=======


****************
1.1.0 2024-10-17
****************

* se renombro __Chibi_atlas_list a Chibi_atlas_list para que no sea raro usarlo
* se agrego a Chibi_atlas_list para que tenga multi append


******************
0.0.1 (2024-02-06)
******************

* First release on PyPI.
